@@ -20,7 +20,7 @@ import docker
 from ruamel.yaml import YAML
 from ruamel.yaml.scalarstring import SingleQuotedScalarString
 
-__version__ = '1.0.1'
+__version__ = '1.0.3'
 
 # name of the environment variable with GitHub token
 GITHUB_TOKEN_KEY = 'GITHUB_TOKEN'
@@ -61,9 +61,17 @@ def _check_call(cmd, **kwargs):
 _check_output = partial(_run_cmd, subprocess.check_output)
 
 
-def _fix_chart_version(version):
+def _fix_chart_version(version, strict=False):
     """
-    Helm 3 requires the Chart.yaml specified version to be SemVer2 compliant.
+    Helm 3 requires published chart versions to follow strict semantic versioning.
+
+    Fix the version if it can be fixed (strip leading `v`),
+    or warn about the chart being unpublishable (default).
+
+    Use `strict=True` if a chart is to be published,
+    since helm 3 will not install a chart with a version that doesn't pass this check.
+
+    This validation is not relevant for charts not being published to a repository.
     """
     # semver.org provided this regular expression:
     # https://semver.org/#is-there-a-suggested-regular-expression-regex-to-check-a-semver-string
@@ -73,10 +81,14 @@ def _fix_chart_version(version):
         return version
 
     if version.startswith("v") and semver2.fullmatch(version[1:]):
-        _log('Stripped a "v" from the chart version to become SemVer 2 compliant as required by Helm 3.')
         return version[1:]
 
-    raise ValueError(f"The version in Chart.yaml '{version}' isn't SemVer2 compliant as required by Helm 3!")
+    message = f"The version in Chart.yaml '{version}' doesn't follow semantic versioning. Helm 3 requires published charts to have strict semantic versions."
+    if strict:
+        raise ValueError(message)
+    else:
+        _log(message)
+        return version
 
 
 def _get_git_remote_url(git_repo):
@@ -553,12 +565,13 @@ def _update_values_file_with_modifications(name, modifications):
                 f'The key {key} in {values_file} must be a mapping or string, not {type(mod_obj)}.'
             )
 
-
     with open(values_file, 'w') as f:
         yaml.dump(values, f)
 
 
-def build_chart(name, version=None, paths=None, long=False, reset=False):
+def build_chart(
+    name, version=None, paths=None, long=False, reset=False, strict_version=False
+):
     """
     Update Chart.yaml's version, using specified version or by constructing one.
 
@@ -583,7 +596,7 @@ def build_chart(name, version=None, paths=None, long=False, reset=False):
     if version is None:
         version = _get_identifier_from_paths(*paths, long=long)
     if not reset:
-        version = _fix_chart_version(version)
+        version = _fix_chart_version(version, strict=strict_version)
 
     # update Chart.yaml
     if chart['version'] != version:
@@ -763,9 +776,10 @@ def main(args=None):
     )
     skip_or_force_build_group = argparser.add_mutually_exclusive_group()
     skip_or_force_build_group.add_argument(
-        '--skip-build',
-        action='store_true',
-        help='Skip the image build step.',
+        "--no-build",
+        "--skip-build",
+        action="store_true",
+        help="Skip the image build step.",
     )
     skip_or_force_build_group.add_argument(
         '--force-build',
@@ -785,13 +799,17 @@ def main(args=None):
     )
 
     args = argparser.parse_args(args)
+    # allow simple checks for whether publish will happen
+    if args.force_publish_chart:
+        args.publish_chart = True
 
     if args.version:
         print(f"chartpress version {__version__}")
         return
 
     if args.list_images:
-        args.skip_build = True
+        args.no_build = True
+
 
     with open('chartpress.yaml') as f:
         config = yaml.load(f)
@@ -810,14 +828,16 @@ def main(args=None):
         if args.reset:
             forced_version = chart.get('resetVersion', '0.0.1-set.by.chartpress')
 
-        # update Chart.yaml with a version
-        chart_version = build_chart(
-            chart['name'],
-            paths=_get_all_chart_paths(chart),
-            version=forced_version,
-            long=args.long,
-            reset=args.reset,
-        )
+        if not args.list_images:
+            # update Chart.yaml with a version
+            chart_version = build_chart(
+                chart['name'],
+                paths=_get_all_chart_paths(chart),
+                version=forced_version,
+                long=args.long,
+                reset=args.reset,
+                strict_version=args.publish_chart,
+            )
 
         if 'images' in chart:
             # build images
@@ -828,7 +848,7 @@ def main(args=None):
                 push=args.push,
                 force_push=args.force_push,
                 force_build=args.force_build,
-                skip_build=args.skip_build or args.reset,
+                skip_build=args.no_build or args.reset,
                 long=args.long,
             )
 
@@ -847,7 +867,7 @@ def main(args=None):
             _update_values_file_with_modifications(chart['name'], values_file_modifications)
 
         # publish chart
-        if args.publish_chart or args.force_publish_chart:
+        if args.publish_chart:
             publish_pages(
                 chart_name=chart['name'],
                 chart_version=chart_version,
